# napari tutorials

These tutorials will help you explore the main usage modes and methods of
napari, and target people who want to use napari. If you are also interested
in contributing to napari then please check out [the Community page](../community/index).

## Improving the tutorials

Our tutorials are hosted on [the napari Github repository](https://github.com/napari/napari).
As you make your way through the tutorials, if you spot any errors or areas that
can be improved, please raise an issue on the repository or make a pull
request! We love it when our community helps make them better for everyone!
To see how to modify documentation pages, please see our
[documentation contributing guide](../developers/documentation/index).